/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.core;

import org.kuehntopf.streamtastic.core.shoutcastfeed.ShoutcastStation;

/**
 * Station base class
 * @author akuehntopf
 */
public class Station 
{
    private String      _name;
    private String      _url;
    private boolean     _recording = false;
     
    /**
     * Constructs a new Station
     */
    public 
    Station()
    {        
    }
    
    /**
     * Constructs a new Station with parameters
     * @param name Name of the Station
     * @param url URL of the Station
     */
    public 
    Station(String name, String url)
    {
        _name = name;
        _url = url;
    }
       
    /**
     * Returns the Station's name
     * @return the name of the station
     */
    public String 
    getName() 
    {
        return _name;
    }

    /**
     * Sets this Station's name
     * @param name
     */
    public void 
    setName(String name) 
    {
        this._name = name;
    }

    /**
     * Returns if the Station is recording
     * @return recording
     */
    public boolean 
    isRecording() 
    {
        return _recording;
    }

    /**
     * Sets this Station's recording status
     * @param recording is this station recording?
     */
    public void 
    setRecording(boolean recording) 
    {
        this._recording = recording;
    }

    /**
     * Returns the Station's url
     * @return the url of the station
     */
    public String 
    getUrl() 
    {
        return _url;
    }

    /**
     * Sets this Station's url
     * @param url
     */
    public void 
    setUrl(String url) 
    {
        this._url = url;
    }     
    
    /**
     * Returns a String representation 
     * of this Station
     * @return string representation
     */
    @Override
    public String 
    toString()
    {
        return getName();
    }

    /**
     * Compares this Object to others
     * @param obj Object to compare to
     * @return are both Objects equal?
     */
    @Override
    public boolean 
    equals(Object obj) 
    {
        if (obj instanceof ShoutcastStation)
        {
            ShoutcastStation s = (ShoutcastStation)obj;
            return s.getUrl().equals(this.getUrl());
        } else if (obj instanceof Station)
        {
            Station s = (Station)obj;
            return s.getUrl().equals(this.getUrl());
        } else
        {
            return super.equals(obj);
        }
    }
    
    /**
     * Returns the HashCode for this Station
     * This is required for correct equals behavior.
     * @return hashcode of this Object
     */
    @Override
    public int 
    hashCode() 
    {
        int hash = 5;
        hash = 47 * hash + (this._url != null ? this._url.hashCode() : 0);
        return hash;
    }            
}