/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.core.storage;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;
import org.kuehntopf.streamtastic.utils.Utilities;

/**
 * Configuration.
 * This class reads and writes properties
 * to a special configuration file. It is used
 * for storing all user preferences
 * @author akuehntopf
 */
public class Config
{
    private static  Config        _instance = null;
    private         Properties    _props;    
    private         String        _fileName = Utilities.getStorageDirectory() + 
            File.separator + "config.properties";
    
    /**
     * Returns the Singleton instance
     * of this class
     */
    public static Config 
    getInstance()
    {
        if (_instance == null)
            _instance = new Config();
        return _instance;
    }
    
    /**
     * Constructs a new ConfigManager object.
     * This is private for Singleton reasons
     */
    public 
    Config()
    {
        _props = new Properties();
        
        File propFile = new File(_fileName);
        
        // Create Configuration file if it
        // doesn't exist
        if (!propFile.exists())
        {
            try
            {
                propFile.createNewFile();
            } catch (IOException ex)
            {
                ex.printStackTrace();
            }
        }
        
        // Finally try loading properties
        loadProperties();
    }
    
    /**
     * Sets a new Property value
     * @param key property key to set
     * @param value the value to set
     */
    public void 
    setProperty(String key, String value)
    {
        _props.setProperty(key, value);
        saveProperties();
    }
    
    /**
     * Gets a Property value
     * @param key key to look for
     * @return the property value
     */
    public String 
    getProperty(String key)
    {
        return _props.getProperty(key);
    }  
           
    /**
     * Saves the properties
     * to disk.
     */
    public void 
    saveProperties()
    {
        try
        {
            File propsFile = new File(_fileName);
            _props.store(new FileOutputStream(propsFile), "Streamtastic");
        } catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }
    
    /**
     * Loads the Properties from
     * disk.
     */
    public void 
    loadProperties()
    {
        try
        {
            _props.load(new FileInputStream(new File(_fileName)));
        } catch (Exception ex)
        {            
            ex.printStackTrace();
        }
    }  
}