/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.core.storage;

import java.beans.XMLDecoder;
import java.beans.XMLEncoder;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.ArrayList;
import java.util.Observable;
import org.kuehntopf.streamtastic.core.CompoundMessage;
import org.kuehntopf.streamtastic.core.Message;
import org.kuehntopf.streamtastic.core.Station;
import org.kuehntopf.streamtastic.utils.Utilities;

/**
 * Class for managing Favorites
 * @author akuehntopf
 */
public class Favorites extends Observable
{
    private String              _dataFilePath;   
    private ArrayList<Station>  _favorites;
    private static Favorites    _instance;
    
    /**
     * Constructs a new Manager object
     */
    private 
    Favorites()
    {
        _favorites = new ArrayList<Station>();
        _dataFilePath = Utilities.getStorageDirectory() +
                                    File.separator + "favorites.xml";
        
        // Load data if file exists
        if (new File(_dataFilePath).exists())
            load();           
    }
    
    /**
     * Returns the singleton instance of this
     * class.
     */
    public static Favorites 
    getInstance()
    {
        if (_instance == null)
            _instance = new Favorites();
        return _instance;           
    }
        
    /**
     * Loads the Favorites from 
     * disk
     */
    public void 
    load()
    {   
        try
        {
            XMLDecoder d = new XMLDecoder(new BufferedInputStream(
                    new FileInputStream(_dataFilePath)));
            Object favObject = d.readObject();
            _favorites = (ArrayList<Station>)favObject;            
        } catch (Exception e)
        {
            e.printStackTrace();
        }
    }
    
    /**
     * Serializes the Favorites to disk.
     */
    public void 
    save()
    {
        try
        {
            XMLEncoder e = new XMLEncoder(new BufferedOutputStream(
                    new FileOutputStream(_dataFilePath)));
            e.writeObject(_favorites);
            e.close();
        } catch (Exception e)
        {
            e.printStackTrace();
        }
    }
    
    /**
     * Adds a new Favorite
     * @param url URL
     * @param description Description
     */
    public void 
    addFavorite(String url, String description)
    {
        Station f = new Station(description, url);
        _favorites.add(f);
        setChanged();
        notifyObservers(new CompoundMessage(Message.FAV_CREATED, f));
        save();
    }
    
    /**
     * Deletes a Favorite
     * @param f Favorite to delete
     */
    public void 
    removeFavorite(Station s)
    {
        _favorites.remove(s);
        setChanged();
        notifyObservers(new CompoundMessage(Message.FAV_REMOVED, s));
        save();
    }
    
    /**
     * Returns a List of all Favorites
     * @return a list of all Favorites
     */
    public ArrayList<Station> 
    getFavorites()
    {
        return _favorites;
    }    
}
