/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui;

import java.io.File;
import javax.swing.JFileChooser;
import javax.swing.JOptionPane;
import org.kuehntopf.streamtastic.core.storage.Config;
import org.kuehntopf.streamtastic.utils.Utilities;

/**
 * Dialog for initially selecting the destination 
 * Directory. This could be done through the preferences
 * dialog as well, but showing all Options on the first
 * Program start would overwhelm the user.
 * @author Andreas Kuehntopf
 */
public class SelectDestinationFrame extends javax.swing.JDialog
{
    /** 
     * Creates new form SelectDestinationFrame 
     */
    public 
    SelectDestinationFrame() 
    {        
        initComponents();
        
        // Center Window on Screen
        setLocationRelativeTo(null);
        
        // Setup header
        header.setCaption(Utilities.getString("SELDEST_HEADER_TEXT"));               
    }
       
    /**
     * Validates the currently selected
     * Destination Directory
     */
    private boolean 
    validateSelectedDir()
    {
        File f = new File(tfDirectory.getText());
        if (!f.isDirectory())
            return false;
        else
            return true;        
    }
    
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        lblInfo = new javax.swing.JLabel();
        btnOk = new javax.swing.JButton();
        btnCancel = new javax.swing.JButton();
        tfDirectory = new javax.swing.JTextField();
        btnSelect = new javax.swing.JButton();
        header = new org.kuehntopf.streamtastic.gui.components.GlossyPanel();

        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        setTitle(Utilities.getString("SELDEST_TITLE")); // NOI18N
        setResizable(false);
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                formWindowClosing(evt);
            }
        });

        lblInfo.setText(Utilities.getString("SELDEST_INFO")); // NOI18N

        btnOk.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/accept.png"))); // NOI18N
        btnOk.setText(Utilities.getString("OK")); // NOI18N
        btnOk.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnOkActionPerformed(evt);
            }
        });

        btnCancel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/cancel.png"))); // NOI18N
        btnCancel.setText(Utilities.getString("CANCEL")); // NOI18N
        btnCancel.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnCancelActionPerformed(evt);
            }
        });

        tfDirectory.setEditable(false);
        tfDirectory.setText(Utilities.getString("SELDEST_PLEASE_SELECT")); // NOI18N

        btnSelect.setText("...");
        btnSelect.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnSelectActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                        .addComponent(btnCancel)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(btnOk))
                    .addComponent(lblInfo, javax.swing.GroupLayout.PREFERRED_SIZE, 384, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(tfDirectory, javax.swing.GroupLayout.DEFAULT_SIZE, 363, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(btnSelect)))
                .addContainerGap())
            .addComponent(header, javax.swing.GroupLayout.DEFAULT_SIZE, 417, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(header, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(lblInfo, javax.swing.GroupLayout.PREFERRED_SIZE, 63, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 10, Short.MAX_VALUE)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(tfDirectory, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(btnSelect))
                .addGap(14, 14, 14)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(btnOk)
                    .addComponent(btnCancel))
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    /**
     * This starts the directory chooser
     * so that the user can easily select his
     * preferred destination directory.
     * @param evt ActionEvent
     */
    private void btnSelectActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnSelectActionPerformed
        JFileChooser fc = new JFileChooser();
        fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
        int ret = fc.showOpenDialog(this);
        if (ret == JFileChooser.APPROVE_OPTION)
        {
            tfDirectory.setText(fc.getSelectedFile().getAbsolutePath());
        }
}//GEN-LAST:event_btnSelectActionPerformed

    /**
     * If the user presses cancel we can safely
     * quit the main program as we cannot continue operating
     * without a destination directory. Before exiting the
     * user will be asked if he really wants to quit.
     * @param evt ActionEvent
     */
    private void btnCancelActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnCancelActionPerformed
        // Ask user for confirmation
        int ret = JOptionPane.showConfirmDialog(this, 
                Utilities.getString("SELDEST_REALLY_QUIT"),
                "Streamtastic",
                JOptionPane.OK_CANCEL_OPTION);
        
        // If the user really pressed OK
        // terminate
        if (ret == JOptionPane.OK_OPTION)
            System.exit(1); 
    }//GEN-LAST:event_btnCancelActionPerformed

    /**
     * If Ok is pressed we save the selected
     * destination directory and continue default program execution
     * @param evt ActionEvent
     */
    private void btnOkActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnOkActionPerformed
        if (validateSelectedDir())
        {
            Config mgr = Config.getInstance();
            mgr.setProperty("DESTINATION_DIR", tfDirectory.getText());
            dispose();
        } else 
        {
            Utilities.showError(Utilities.getString("SELDEST_DEST_NOT_VALID"));
        }
    }//GEN-LAST:event_btnOkActionPerformed

    /**
     * If the form is closed,
     * ask for confirmation
     * @param evt WindowEvent
     */
    private void formWindowClosing(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_formWindowClosing
        btnCancelActionPerformed(null);        
    }//GEN-LAST:event_formWindowClosing
          
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btnCancel;
    private javax.swing.JButton btnOk;
    private javax.swing.JButton btnSelect;
    private org.kuehntopf.streamtastic.gui.components.GlossyPanel header;
    private javax.swing.JLabel lblInfo;
    private javax.swing.JTextField tfDirectory;
    // End of variables declaration//GEN-END:variables
   
}
