/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui;

import java.awt.CardLayout;
import java.awt.Cursor;
import java.awt.Dimension;
import javax.swing.DefaultListModel;
import javax.swing.JLabel;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import org.kuehntopf.streamtastic.core.storage.Config;
import org.kuehntopf.streamtastic.gui.components.BusyGlassPane;
import org.kuehntopf.streamtastic.gui.components.SidebarMenuCellRenderer;
import org.kuehntopf.streamtastic.gui.views.DownloadsView;
import org.kuehntopf.streamtastic.gui.views.FavoritesView;
import org.kuehntopf.streamtastic.gui.views.ShoutcastView;
import org.kuehntopf.streamtastic.gui.views.View;
import org.kuehntopf.streamtastic.utils.Utilities;

/**
 * Main frame
 * @author  akuehntopf
 */
public class StreamtasticFrame extends javax.swing.JFrame 
{
    private CardLayout _cards;
    
    /** 
     * Creates new form StreamtasticFrame 
     */
    public 
    StreamtasticFrame() 
    {
        initComponents();
                
        // Init Glasspane
        setGlassPane(new BusyGlassPane());
               
        // Add Views
        _cards = new CardLayout();
        switcher.setLayout(_cards);
        switcher.add(new FavoritesView(this), "0");
        switcher.add(new ShoutcastView(this), "1");         
        switcher.add(new DownloadsView(this), "2");                
        
        // Init Sidebar
        initSidebar();
        
        // Restore status
        loadWindowStatus();
    }
    
    
    /**
     * Initializes the Sidebar
     */
    private void 
    initSidebar()
    {
        DefaultListModel sidebarmodel= new DefaultListModel();
        
         // Setup list
        sidebarmenu.setCellRenderer(new SidebarMenuCellRenderer());
        sidebarmenu.setFixedCellHeight(30);
        sidebarmenu.setModel(sidebarmodel);
        
        // Add Menu items
        JLabel lblFavorites = new JLabel(Utilities.getString("SIDEBARMENU_FAVORITES"),
                                         Utilities.loadIcon("small/favorites.png"),
                                         0);
        JLabel lblShoutcast = new JLabel(Utilities.getString("SIDEBARMENU_SHOUTCAST"),
                                         Utilities.loadIcon("small/shoutcast.png"),
                                         0);        
        JLabel lblDownloads = new JLabel(Utilities.getString("SIDEBARMENU_DOWNLOADS"),
                                         Utilities.loadIcon("small/radio.png"),
                                         0);        
        sidebarmodel.addElement(lblFavorites);
        sidebarmodel.addElement(lblShoutcast);
        sidebarmodel.addElement(lblDownloads);
        
        
        // Add listener for reacting to selection changes
        sidebarmenu.addListSelectionListener(new ListSelectionListener() 
        {
            public void valueChanged(ListSelectionEvent arg0) 
            {
                if (arg0.getValueIsAdjusting() == true)
                    return;
                
                int selIndex = sidebarmenu.getSelectedIndex(); 
                _cards.show(switcher, String.valueOf(selIndex));
                // Tell the View that it got activated now
                View v = (View)switcher.getComponent(selIndex);
                v.activate();
            }
        });        
        
        // Select item 0 by default
        sidebarmenu.setSelectedIndex(0);
    }
    
    /**
     * Sets the busy status
     * @param busy
     */
    public void 
    setBusy(boolean busy)            
    {
        if (busy)
            setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
        else
            setCursor(Cursor.getDefaultCursor());
        
        getGlassPane().setVisible(busy);
    }
    
    /**
     * Sets the status text 
     * of this frame
     * @param text text to set
     */
    public void 
    setStatus(String text)
    {
        statusbar.setText(text);
    }
    
    /**
     * Loads the current Window location
     * from the Config
     */
    private void
    loadWindowStatus()
    {
        String winX = Config.getInstance().getProperty("WINDOW_X");
        String winY = Config.getInstance().getProperty("WINDOW_Y");
        String winW = Config.getInstance().getProperty("WINDOW_W");
        String winH = Config.getInstance().getProperty("WINDOW_H");
        
        if (winW != null && winH != null)
        {
            setSize(Integer.valueOf(winW), Integer.valueOf(winH));
            setPreferredSize(new Dimension(Integer.valueOf(winW), Integer.valueOf(winH)));
        }
        
        if (winX != null && winY != null)
        {
            setLocation(Integer.valueOf(winX), Integer.valueOf(winY ));
        }
    }
    
    /**
     * Saves the current Window location to the Config
     */
    private void
    saveWindowStatus()
    {
        Config.getInstance().setProperty("WINDOW_X", String.valueOf(getX()));
        Config.getInstance().setProperty("WINDOW_Y", String.valueOf(getY()));
        Config.getInstance().setProperty("WINDOW_W", String.valueOf(getWidth()));
        Config.getInstance().setProperty("WINDOW_H", String.valueOf(getHeight()));
    }

    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        splitpane = new javax.swing.JSplitPane();
        scrollpane = new javax.swing.JScrollPane();
        sidebarmenu = new org.jdesktop.swingx.JXList();
        switcher = new org.jdesktop.swingx.JXPanel();
        statusbar = new javax.swing.JLabel();
        menubar = new javax.swing.JMenuBar();
        mnuFile = new javax.swing.JMenu();
        mnuFileQuit = new javax.swing.JMenuItem();
        mnuHelp = new javax.swing.JMenu();
        mnuHelpAbout = new javax.swing.JMenuItem();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setTitle(Utilities.getString("MAINFRAME_TITLE")); // NOI18N
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosed(java.awt.event.WindowEvent evt) {
                formWindowClosed(evt);
            }
            public void windowClosing(java.awt.event.WindowEvent evt) {
                formWindowClosing(evt);
            }
        });

        splitpane.setDividerLocation(150);
        splitpane.setDividerSize(5);

        sidebarmenu.setBackground(java.awt.Color.white);
        scrollpane.setViewportView(sidebarmenu);

        splitpane.setLeftComponent(scrollpane);

        switcher.setLayout(null);
        splitpane.setRightComponent(switcher);

        statusbar.setText(Utilities.getString("MAINFRAME_INITIAL_STATUSTEXT")); // NOI18N

        mnuFile.setText(Utilities.getString("MAINFRAME_MNU_FILE")); // NOI18N

        mnuFileQuit.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/quit.png"))); // NOI18N
        mnuFileQuit.setText(Utilities.getString("MAINFRAME_MNU_FILE_QUIT")); // NOI18N
        mnuFileQuit.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                mnuFileQuitActionPerformed(evt);
            }
        });
        mnuFile.add(mnuFileQuit);

        menubar.add(mnuFile);

        mnuHelp.setText(Utilities.getString("MAINFRAME_MNU_HELP")); // NOI18N

        mnuHelpAbout.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/info.png"))); // NOI18N
        mnuHelpAbout.setText(Utilities.getString("MAINFRAME_MNU_HELP_ABOUT")); // NOI18N
        mnuHelpAbout.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                mnuHelpAboutActionPerformed(evt);
            }
        });
        mnuHelp.add(mnuHelpAbout);

        menubar.add(mnuHelp);

        setJMenuBar(menubar);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(splitpane, javax.swing.GroupLayout.DEFAULT_SIZE, 766, Short.MAX_VALUE)
            .addComponent(statusbar, javax.swing.GroupLayout.DEFAULT_SIZE, 766, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addComponent(splitpane, javax.swing.GroupLayout.DEFAULT_SIZE, 451, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(statusbar, javax.swing.GroupLayout.PREFERRED_SIZE, 17, javax.swing.GroupLayout.PREFERRED_SIZE))
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void mnuHelpAboutActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_mnuHelpAboutActionPerformed
        new AboutFrame().setVisible(true);
    }//GEN-LAST:event_mnuHelpAboutActionPerformed

    private void mnuFileQuitActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_mnuFileQuitActionPerformed
        dispose();
    }//GEN-LAST:event_mnuFileQuitActionPerformed

    /**
     * Reacts to X button presses
     * @param evt
     */
    private void formWindowClosing(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_formWindowClosing
        saveWindowStatus();
    }//GEN-LAST:event_formWindowClosing

    /**
     * This one reacts to calls to dispose();
     */
    private void formWindowClosed(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_formWindowClosed
        saveWindowStatus();
    }//GEN-LAST:event_formWindowClosed
 
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JMenuBar menubar;
    private javax.swing.JMenu mnuFile;
    private javax.swing.JMenuItem mnuFileQuit;
    private javax.swing.JMenu mnuHelp;
    private javax.swing.JMenuItem mnuHelpAbout;
    private javax.swing.JScrollPane scrollpane;
    private org.jdesktop.swingx.JXList sidebarmenu;
    private javax.swing.JSplitPane splitpane;
    private javax.swing.JLabel statusbar;
    private org.jdesktop.swingx.JXPanel switcher;
    // End of variables declaration//GEN-END:variables
    
}
