/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui.components;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.event.KeyAdapter;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseMotionAdapter;
import org.jdesktop.swingx.JXBusyLabel;
import org.jdesktop.swingx.JXPanel;
import org.jdesktop.swingx.painter.MattePainter;

/**
 * JXPanel, which acts as a busy indicator
 * Input to Components below is disabled. 
 * @author akuehntopf
 */
public class BusyGlassPane extends JXPanel
{
    private JXBusyLabel _lbl;
    
    /**
     * Constructs a new BusyGlassPane
     */
    public 
    BusyGlassPane()
    {
        _lbl = new JXBusyLabel(new Dimension(150, 150));     
                        
        // Set layout and add Label
        setLayout(new BorderLayout());
        _lbl.setHorizontalAlignment(JXBusyLabel.CENTER);
        add(_lbl, BorderLayout.CENTER);
        // Stop Input events from reaching components below
        addMouseListener(new MouseAdapter() {});
        addKeyListener(new KeyAdapter() {});
        addMouseMotionListener(new MouseMotionAdapter() {});
        // This component is the source for further Focus actions
        setFocusCycleRoot(true);
        // Setup painter
        setOpaque(false);
        setBackgroundPainter(new MattePainter(
                new Color(1.0f, 1.0f, 1.0f, 0.6f)));
    }    
    
    @Override
    public void
    setVisible(boolean visible)
    {
        super.setVisible(visible);
        _lbl.setBusy(visible);
    }            
}
