/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui.components;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import org.jdesktop.swingx.JXPanel;
import org.jdesktop.swingx.painter.CompoundPainter;
import org.jdesktop.swingx.painter.GlossPainter;
import org.jdesktop.swingx.painter.PinstripePainter;

/**
 * JXPanel subclass with glossy background
 * and pinstripes
 * @author akuehntopf
 */
public class GlossyPanel extends JXPanel
{
    private JLabel _lblCaption;
    private JLabel _lblIcon;
    
    /**
     * Constructor
     */
    public 
    GlossyPanel()
    {
        // Setup painters and paint the background
        GlossPainter gloss = new GlossPainter(
                new Color(1.0f, 1.0f, 1.0f, 0.5f));
        
        PinstripePainter pinstripes = new PinstripePainter(
                new Color(0.1f, 0.1f, 0.1f, 0.2f));
        
        pinstripes.setSpacing(5);
        
        CompoundPainter ptr = new CompoundPainter(pinstripes, gloss);
        setBackgroundPainter(ptr);           
        
        // Setup Border and Layout
        setBorder(BorderFactory.createEmptyBorder(0, 10, 0, 10));
        setLayout(new BorderLayout());
        
        // Label settings
        _lblCaption = new JLabel();
        _lblIcon = new JLabel();        
        _lblCaption.setFont(new Font("Dialog", Font.BOLD, 14));
        _lblCaption.setHorizontalAlignment(JLabel.LEADING);                                
        _lblIcon.setHorizontalAlignment(JLabel.TRAILING);       
        
        // Add labels to panel
        add(_lblCaption, BorderLayout.CENTER);
        add(_lblIcon, BorderLayout.EAST);
    }
    
    /**
     * Sets this Panel's caption
     * @param text Caption to set
     */
    public void 
    setCaption(String text)
    {
        _lblCaption.setText(text);
    }
        
    /**
     * Sets this Panel's icon
     * @param icon Icon to set
     */
    public void 
    setIcon(ImageIcon icon)
    {
        _lblIcon.setIcon(icon);
    }    
}
