/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui.models;

import java.util.ArrayList;
import java.util.Observable;
import java.util.Observer;
import javax.swing.table.AbstractTableModel;
import org.kuehntopf.streamtastic.core.streamripper.StreamRipper;
import org.kuehntopf.streamtastic.core.CompoundMessage;
import org.kuehntopf.streamtastic.core.RippingManager;
import org.kuehntopf.streamtastic.utils.Utilities;

public class DownloadsTableModel extends AbstractTableModel implements Observer
{
    String lblColStatus = Utilities.getString("DLS_COL_STATUS");
    String lblColName = Utilities.getString("DLS_COL_NAME");
    String lblColCurrent = Utilities.getString("DLS_COL_CURRENT");
    String lblColTransferred = Utilities.getString("DLS_COL_TRANSFERRED");
    
    private ArrayList<StreamRipper> _rippers;
    private String[]                _cols = new String[]
                                    {lblColStatus, lblColName,
                                     lblColCurrent, lblColTransferred};
    
    /**
     * Constructs a new Downloads Table Model
     */
    public 
    DownloadsTableModel()
    {    
        _rippers = (ArrayList<StreamRipper>) RippingManager.getInstance().getRippers().clone();
        RippingManager.getInstance().addObserver(this);
    }

    /**
     * Returns the column's name
     * @param col column
     * @return the column's name
     */
    @Override
    public String 
    getColumnName(int col)
    {
        return _cols[col];
    }
    
    /**
     * Returns the number of rows
     * @return the number of rows
     */
    public int 
    getRowCount()
    {
        return _rippers.size();
    }

    /**
     * Returns the number of columns
     * @return the number of columns
     */
    public int 
    getColumnCount()
    {
        return _cols.length;
    }

    /**
     * Returns a Value from the model
     * for a specific row and column
     * @param row row
     * @param col column
     * @return the value for the specified row and column
     */
    public Object 
    getValueAt(int row, int col)
    {
        StreamRipper ripper = _rippers.get(row);
        
        switch(col)
        {
            case 0:
                return ripper.getStatus();
            case 1:
                return ripper.getName();
            case 2:
                return ripper.getTrack();
            case 3:
                return ripper.getTransferred();              
        }
        
        return null;
    }
    
    /**
     * Returns the Ripper at the given position
     * @param row Position
     * @return the ripper
     */
    public StreamRipper 
    getRipperAt(int row)
    {
        return _rippers.get(row);
    }
    
    public StreamRipper[] getRippers() {
    	return _rippers.toArray(new StreamRipper[_rippers.size()]);
    }

    /**
     * Observer method which gets called
     * whenever the RippingManager changes its status
     * @param arg0
     * @param arg1
     */
    public void 
    update(Observable obs, Object obj)
    {
        CompoundMessage msg = (CompoundMessage)obj;
        switch (msg.getMessage())
        {
            case RIP_UPDATED:                
                int pos = _rippers.indexOf(msg.getObject());                          
                fireTableRowsUpdated(pos, pos);
                break;
                
            case RIP_REMOVED:
                pos = _rippers.indexOf(msg.getObject());
                _rippers.remove(msg.getObject());
                fireTableRowsDeleted(pos, pos);
                break;
                
            case RIP_CREATED:
                _rippers.add((StreamRipper)msg.getObject());
                pos = _rippers.indexOf(msg.getObject());
                fireTableRowsInserted(pos, pos);
                break;
                
            default:
                fireTableDataChanged();        
        }        
    }
}
