/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui.models;

import java.util.Observable;
import java.util.Observer;
import javax.swing.table.AbstractTableModel;
import org.kuehntopf.streamtastic.core.RippingManager;
import org.kuehntopf.streamtastic.core.Station;
import org.kuehntopf.streamtastic.core.storage.Favorites;
import org.kuehntopf.streamtastic.utils.Utilities;


/**
 * Table Model for displaying and editing favorites
 * @author Andreas Kuehntopf
 */
public class FavoritesTableModel extends AbstractTableModel implements Observer 
{
    private String lblColURL = Utilities.getString("FAVS_COL_URL");
    private String lblColDesc = Utilities.getString("FAVS_COL_DESC");
    
    private Favorites           _favs;
    private Class[]             _classes = {String.class, String.class};
    private String[]            _names = {lblColDesc, lblColURL};
    

    /**
     * Constructs a new Favorites Table Model
     */   
    public 
    FavoritesTableModel()
    {        
        _favs = Favorites.getInstance();
        _favs.addObserver(this);   
    }
    
    /**
     * Returns if a given cell is editable
     * @param row
     * @param col
     * @return true if the cell is editable
     */
    @Override
    public boolean 
    isCellEditable(int row, int col)
    {
        // Everything is editable
        return true;
    }

    /**
     * Returns the number of rows
     * @return the number of rows
     */
    public int 
    getRowCount()
    {
        return _favs.getFavorites().size();
    }

    /**
     * Returns the class of a specific column
     * @param col column
     * @return the class of the given column
     */
    @Override
    public Class<?> 
    getColumnClass(int col)
    {
        return _classes[col];
    }

    /**
     * Returns the name of a specific column
     * @param col column
     * @return the name of the given column
     */
    @Override
    public String 
    getColumnName(int arg0)
    {
        return _names[arg0];
    }

    /**
     * Sets the value of a cell
     * @param value value to set
     * @param row row
     * @param col column
     */
    @Override
    public void 
    setValueAt(Object value, int row, int col)            
    {
        Station f = (Station)_favs.getFavorites().get(row);
        
        switch (col)
        {
            case 0:
                f.setName((String)value);
                break;
            case 1:                
                f.setUrl((String)value);
                break;
        }
        Favorites.getInstance().save();
        fireTableCellUpdated(row, col);
    }

    /**
     * Returns the number of columns
     * @return the number of columns
     */
    public int 
    getColumnCount()
    {
        return 2;
    }

    /**
     * Returns the value of a specific cell
     * @param row row
     * @param col column
     * @return the value of the specified cell
     */
    public Object 
    getValueAt(int row, int col)
    {
        Station f = (Station)_favs.getFavorites().get(row);
        
        switch (col)
        {
            case 0:
                return f;
            default:
                return f.getUrl();
        }
    }

    /**
     * Returns a favorite at a specific row
     * @param row
     * @return favorite
     */
    public Station
    getFavoriteAt(int row)
    {
        return _favs.getFavorites().get(row);
    }
    
    /**
     * This gets called whenever the FavoritesManager changes
     * its state
     * @param obs Observable
     * @param obj Message
     */
    public void 
    update(Observable obs, Object message)
    {
        fireTableDataChanged();
    }
}
