/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui.models;

import java.util.List;
import java.util.Vector;

import javax.swing.table.AbstractTableModel;

import org.kuehntopf.streamtastic.core.shoutcastfeed.ShoutcastStation;
import org.kuehntopf.streamtastic.utils.Utilities;

/**
 * TableModel for displaying shoutcast stations
 * @author akuehntopf
 */
public class ShoutcastTableModel extends AbstractTableModel        
{     
    private String[] colNames = new String[]
    {
        Utilities.getString("SHOUT_COL_NAME"),
        Utilities.getString("SHOUT_COL_CURRENT"),
        Utilities.getString("SHOUT_COL_LISTENERS"),
        Utilities.getString("SHOUT_COL_BITRATE")
    };   
    
    private Class[] colClasses = new Class[]
    {
        Object.class, 
        String.class, 
        Integer.class,
        Integer.class
    };
    
    private Vector<ShoutcastStation> _stations = new Vector<ShoutcastStation>();
    
    public int getRowCount() 
    {
        return _stations.size();
    }

    public int getColumnCount() 
    {
        return colNames.length;
    }

    @Override
    public String getColumnName(int col) 
    {
        return colNames[col];
    }

    @Override
    public Class<?> getColumnClass(int arg0) {
        return colClasses[arg0];
    }

    public Object getValueAt(int row, int col) 
    {
        ShoutcastStation s = (ShoutcastStation)_stations.get(row);
        
        switch (col)
        {
            case 0:
                return s;
            case 1:
                return s.getCurrentTrack();
            case 2:
                return s.getListeners();
            case 3:
                return s.getBitrate();
        }
                
        return null;
    }
    
    public void setStations(List<ShoutcastStation> stations)
    {
        _stations.clear();
        _stations.addAll(stations);
        fireTableDataChanged();
    }
   
    public void clear()
    {
        _stations.clear();
        fireTableDataChanged();
    }
}
