/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui.views;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JOptionPane;
import javax.swing.SwingWorker;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import org.kuehntopf.streamtastic.core.storage.Favorites;
import org.kuehntopf.streamtastic.utils.Utilities;
import org.kuehntopf.streamtastic.gui.views.View;
import org.kuehntopf.streamtastic.gui.models.DownloadsTableModel;
import org.kuehntopf.streamtastic.core.streamripper.StreamRipper;
import org.kuehntopf.streamtastic.gui.StreamtasticFrame;

/**
 * View for managing downloads
 * @author Andreas Kuehntopf
 */
public class DownloadsView extends javax.swing.JPanel implements View
{    
    private DownloadsTableModel _model;
    private StreamtasticFrame   _parent = null;
    
    /** 
     * Creates new form DownloadsView 
     */
    private 
    DownloadsView() 
    {
        initComponents();
        
        // Setup header        
        header.setCaption("Downloads");
        header.setIcon(Utilities.loadIcon("large/radio.png"));
        
        // Setup table
        _model = new DownloadsTableModel();
        tblDownloads.setModel(_model);             
        tblDownloads.getSelectionModel().addListSelectionListener(new ListSelectionListener() 
        {
            public void valueChanged(ListSelectionEvent arg0) 
            {
                updateButtons();
            }
        });
                
        // Initially load Status
        updateButtons();
    }    
    
    public 
    DownloadsView(StreamtasticFrame parent)
    {        
        this();
        _parent = parent;
        
        //cancel all downloads when streamtastic is closed
        _parent.addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent e) {
                cancelAllRippers();
            }
        });
    }
    
    /**
     * Gets called when the View is activated
     */
    public void 
    activate() 
    {
        // NO-OP
    }

    /**
     * Updates buttons according to 
     * selection
     */
    private void
    updateButtons()
    {
        if (getCurrentRipper() == null)
        {
            btnAddToFavs.setVisible(false);
            btnCancel.setVisible(false);
        } else
        {
            btnAddToFavs.setVisible(true);
            btnCancel.setVisible(true);            
        }
    }
    
    /**
     * Gets the currently selected Ripper
     * @return current ripper or null
     */
    private StreamRipper
    getCurrentRipper()
    {
        int selPos = tblDownloads.getSelectedRow();
        if (selPos == -1)
            return null;
        return _model.getRipperAt(selPos);
    }
       
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        scrollpane = new javax.swing.JScrollPane();
        tblDownloads = new javax.swing.JTable();
        header = new org.kuehntopf.streamtastic.gui.components.GlossyPanel();
        toolbar = new javax.swing.JToolBar();
        btnAddToFavs = new javax.swing.JButton();
        btnCancel = new javax.swing.JButton();
        btnCancelAll = new javax.swing.JButton();

        scrollpane.setViewportView(tblDownloads);

        toolbar.setBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(166, 166, 166)));
        toolbar.setFloatable(false);
        toolbar.setRollover(true);

        btnAddToFavs.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/favorites.png"))); // NOI18N
        btnAddToFavs.setToolTipText(Utilities.getString("DLS_ADD_TO_FAVS")); // NOI18N
        btnAddToFavs.setFocusable(false);
        btnAddToFavs.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        btnAddToFavs.setMaximumSize(new java.awt.Dimension(48, 48));
        btnAddToFavs.setMinimumSize(new java.awt.Dimension(48, 48));
        btnAddToFavs.setPreferredSize(new java.awt.Dimension(32, 32));
        btnAddToFavs.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        btnAddToFavs.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnAddToFavsActionPerformed(evt);
            }
        });
        toolbar.add(btnAddToFavs);

        btnCancel.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/cancel.png"))); // NOI18N
        btnCancel.setToolTipText(Utilities.getString("CANCEL")); // NOI18N
        btnCancel.setFocusable(false);
        btnCancel.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        btnCancel.setMaximumSize(new java.awt.Dimension(48, 48));
        btnCancel.setMinimumSize(new java.awt.Dimension(48, 48));
        btnCancel.setPreferredSize(new java.awt.Dimension(32, 32));
        btnCancel.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        btnCancel.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnCancelActionPerformed(evt);
            }
        });
        toolbar.add(btnCancel);

        btnCancelAll.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/cancel_all.png"))); // NOI18N
        btnCancelAll.setToolTipText(Utilities.getString("CANCEL_ALL")); // NOI18N
        btnCancelAll.setFocusable(false);
        btnCancelAll.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        btnCancelAll.setMaximumSize(new java.awt.Dimension(48, 48));
        btnCancelAll.setMinimumSize(new java.awt.Dimension(48, 48));
        btnCancelAll.setPreferredSize(new java.awt.Dimension(32, 32));
        btnCancelAll.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        btnCancelAll.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnCancelAllActionPerformed(evt);
            }
        });
        toolbar.add(btnCancelAll);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(header, javax.swing.GroupLayout.DEFAULT_SIZE, 552, Short.MAX_VALUE)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(toolbar, javax.swing.GroupLayout.DEFAULT_SIZE, 528, Short.MAX_VALUE)
                .addContainerGap())
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(scrollpane, javax.swing.GroupLayout.DEFAULT_SIZE, 528, Short.MAX_VALUE)
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(header, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(scrollpane, javax.swing.GroupLayout.DEFAULT_SIZE, 281, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(toolbar, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
        );
    }// </editor-fold>//GEN-END:initComponents

private void btnAddToFavsActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnAddToFavsActionPerformed
    StreamRipper current = getCurrentRipper();
    Favorites.getInstance().addFavorite(current.getUrl(), current.getName());
}//GEN-LAST:event_btnAddToFavsActionPerformed

private void btnCancelActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnCancelActionPerformed
    StreamRipper current = getCurrentRipper();
    current.stop();
}//GEN-LAST:event_btnCancelActionPerformed

private void cancelAllRippers() {
    // Cancel all Rippers
    // We are going for the DownloadTableModel here because we may not
    // modify the RippingManager arraylist concurrently (stop() causes removeRip
    // to be called)
    SwingWorker worker = new SwingWorker<Void, Void>() 
    {
        @Override
        protected Void doInBackground() throws Exception 
        {                          
            for (StreamRipper ripper:_model.getRippers()) ripper.stop();
            
            return null;
        }

        @Override
        protected void done() 
        {   
            _parent.setBusy(false);
        }
     };
    
     _parent.setBusy(true);
     worker.execute();
}

private void btnCancelAllActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnCancelAllActionPerformed
        
    // Ask user for confirmation
    int ret = JOptionPane.showConfirmDialog(this, 
            Utilities.getString("DLS_REALLY_CANCEL_ALL"),
            "Streamtastic",
            JOptionPane.OK_CANCEL_OPTION);

    // If the user did not press OK: cancel
    if (ret != JOptionPane.OK_OPTION)
        return;    
    
    // If there are no rows, there is nothing to cancel
    if (_model.getRowCount() == 0)
        return;
    
    cancelAllRippers();
    
}//GEN-LAST:event_btnCancelAllActionPerformed
      
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btnAddToFavs;
    private javax.swing.JButton btnCancel;
    private javax.swing.JButton btnCancelAll;
    private org.kuehntopf.streamtastic.gui.components.GlossyPanel header;
    private javax.swing.JScrollPane scrollpane;
    private javax.swing.JTable tblDownloads;
    private javax.swing.JToolBar toolbar;
    // End of variables declaration//GEN-END:variables

}
