/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.gui.views;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Observable;
import java.util.Observer;
import javax.swing.JOptionPane;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import org.kuehntopf.streamtastic.core.CompoundMessage;
import org.kuehntopf.streamtastic.core.Message;
import org.kuehntopf.streamtastic.core.RippingManager;
import org.kuehntopf.streamtastic.core.Station;
import org.kuehntopf.streamtastic.core.storage.Favorites;
import org.kuehntopf.streamtastic.gui.StreamtasticFrame;
import org.kuehntopf.streamtastic.gui.components.StationTableCellRenderer;
import org.kuehntopf.streamtastic.utils.Utilities;
import org.kuehntopf.streamtastic.gui.views.View;
import org.kuehntopf.streamtastic.gui.models.FavoritesTableModel;

/**
 * View for managing favorite stations
 * @author akuehntopf
 */
public class FavoritesView extends javax.swing.JPanel implements View, Observer
{    
    private Favorites           _favmgr;
    private FavoritesTableModel _model;
    private StreamtasticFrame   _parent = null;
    
    /** 
     * Creates new form FavoritesView 
     */
    public FavoritesView()
    {
        initComponents();
        
        // Setup header
        header.setCaption(Utilities.getString("FAVS_HEADER_TEXT"));
        header.setIcon(Utilities.loadIcon("large/favorites.png"));
        _model = new FavoritesTableModel();
        tblFavorites.setModel(_model);
        tblFavorites.setDefaultRenderer(Object.class, new StationTableCellRenderer());     
        
        // Add myself to RippingManager observers
        RippingManager.getInstance().addObserver(this);
        
        // Initially update buttons
        updateButtons();
        
        tblFavorites.getSelectionModel().addListSelectionListener(new ListSelectionListener() 
        {            
            public void valueChanged(ListSelectionEvent arg0) 
            {
                updateButtons();
            }
        });
    }         

        
    public FavoritesView(StreamtasticFrame parent)
    {        
        this();
        _parent = parent;
    }
    
    /**
     * Gets called when the View is activated
     */
    public void activate() 
    {
    }
    
    private void
    updateButtons()
    {
        Station s = getSelectedFavorite();
        if (s == null)
        {
            btnDelete.setVisible(false);
            btnRecord.setVisible(false);
        } else 
        {
            btnDelete.setVisible(true);
            
            // Set Record button visibile if
            // we are not already downloading
            if (!RippingManager.getInstance().isRipping(s))
                btnRecord.setVisible(true);           
            else
                btnRecord.setVisible(false);
        }
    }
    
    private Station
    getSelectedFavorite()
    {
        int selPos = tblFavorites.getSelectedRow();
        if (selPos == -1)
            return null;
        return _model.getFavoriteAt(selPos);
    }
    
    /**
     * Gets updated when the RippingManager sends a new status
     * @param arg0
     * @param arg1
     */
    public void update(Observable arg0, Object arg1) 
    {
        CompoundMessage msg = (CompoundMessage)arg1;
        if (msg.getMessage().equals(Message.RIP_CREATED) ||
            msg.getMessage().equals(Message.RIP_REMOVED))
            tblFavorites.repaint();
    }
    
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        lblAdd = new javax.swing.JLabel();
        textfieldAdd = new javax.swing.JTextField();
        scrollpane = new javax.swing.JScrollPane();
        tblFavorites = new javax.swing.JTable();
        header = new org.kuehntopf.streamtastic.gui.components.GlossyPanel();
        toolbar = new javax.swing.JToolBar();
        btnRecord = new javax.swing.JButton();
        btnRecordAll = new javax.swing.JButton();
        btnDelete = new javax.swing.JButton();

        lblAdd.setText(Utilities.getString("FAVS_QUICKADD")); // NOI18N

        textfieldAdd.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                textfieldAddActionPerformed(evt);
            }
        });

        tblFavorites.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {

            },
            new String [] {

            }
        ));
        scrollpane.setViewportView(tblFavorites);
        tblFavorites.getColumnModel().getSelectionModel().setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);

        toolbar.setBorder(javax.swing.BorderFactory.createLineBorder(new java.awt.Color(126, 126, 126)));
        toolbar.setFloatable(false);
        toolbar.setRollover(true);

        btnRecord.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/record.png"))); // NOI18N
        btnRecord.setToolTipText(Utilities.getString("RECORD")); // NOI18N
        btnRecord.setFocusable(false);
        btnRecord.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        btnRecord.setMaximumSize(new java.awt.Dimension(48, 48));
        btnRecord.setMinimumSize(new java.awt.Dimension(48, 48));
        btnRecord.setPreferredSize(new java.awt.Dimension(32, 32));
        btnRecord.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        btnRecord.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnRecordActionPerformed(evt);
            }
        });
        toolbar.add(btnRecord);

        btnRecordAll.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/record_all.png"))); // NOI18N
        btnRecordAll.setToolTipText(Utilities.getString("FAVS_RECORD_ALL")); // NOI18N
        btnRecordAll.setFocusable(false);
        btnRecordAll.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        btnRecordAll.setMaximumSize(new java.awt.Dimension(48, 48));
        btnRecordAll.setMinimumSize(new java.awt.Dimension(48, 48));
        btnRecordAll.setPreferredSize(new java.awt.Dimension(32, 32));
        btnRecordAll.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        btnRecordAll.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnRecordAllActionPerformed(evt);
            }
        });
        toolbar.add(btnRecordAll);

        btnDelete.setIcon(new javax.swing.ImageIcon(getClass().getResource("/org/kuehntopf/streamtastic/resources/icons/small/delete.png"))); // NOI18N
        btnDelete.setToolTipText(Utilities.getString("DELETE")); // NOI18N
        btnDelete.setFocusable(false);
        btnDelete.setHorizontalTextPosition(javax.swing.SwingConstants.CENTER);
        btnDelete.setMaximumSize(new java.awt.Dimension(48, 48));
        btnDelete.setMinimumSize(new java.awt.Dimension(48, 48));
        btnDelete.setPreferredSize(new java.awt.Dimension(32, 32));
        btnDelete.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);
        btnDelete.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnDeleteActionPerformed(evt);
            }
        });
        toolbar.add(btnDelete);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(header, javax.swing.GroupLayout.DEFAULT_SIZE, 613, Short.MAX_VALUE)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(toolbar, javax.swing.GroupLayout.DEFAULT_SIZE, 589, Short.MAX_VALUE)
                .addContainerGap())
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(scrollpane, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 589, Short.MAX_VALUE)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(lblAdd)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(textfieldAdd, javax.swing.GroupLayout.DEFAULT_SIZE, 510, Short.MAX_VALUE)))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(header, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(18, 18, 18)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(lblAdd)
                    .addComponent(textfieldAdd, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(scrollpane, javax.swing.GroupLayout.DEFAULT_SIZE, 281, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(toolbar, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE))
        );
    }// </editor-fold>//GEN-END:initComponents

    /**
     * This gets called when the user presses
     * the enter key inside the QuickAdd textfield
     * A new Favorite should be generated
     * @param evt ActionEvent
     */
    private void textfieldAddActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_textfieldAddActionPerformed
        String url = textfieldAdd.getText();
        try
        {            
            URL u = new URL(url);
            Favorites.getInstance().addFavorite(url, "");
        } catch (MalformedURLException ex)
        {
            Utilities.showLocalizedError("FAVS_INVALID_URL");
        }                
    }//GEN-LAST:event_textfieldAddActionPerformed

private void btnRecordActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnRecordActionPerformed
    Station s = getSelectedFavorite();
    RippingManager.getInstance().createRip(s);
    tblFavorites.repaint();
    updateButtons();
}//GEN-LAST:event_btnRecordActionPerformed

private void btnDeleteActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnDeleteActionPerformed
    Favorites.getInstance().removeFavorite(getSelectedFavorite());
}//GEN-LAST:event_btnDeleteActionPerformed

private void btnRecordAllActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnRecordAllActionPerformed
    
     // Ask user for confirmation
    int ret = JOptionPane.showConfirmDialog(this, 
            Utilities.getString("FAVS_REALLY_RECORD_ALL"),
            "Streamtastic",
            JOptionPane.OK_CANCEL_OPTION);

    // If the user did not press OK: cancel
    if (ret != JOptionPane.OK_OPTION)
        return;     
    
    // Get all Favorites
    ArrayList<Station> allFavs = Favorites.getInstance().getFavorites();
    
    // Launch all Stations if not already downloading
    for(Station s: allFavs)
    {
        if (!RippingManager.getInstance().isRipping(s))
            RippingManager.getInstance().createRip(s);
    }
}//GEN-LAST:event_btnRecordAllActionPerformed


    /**
     * User wants to delete a Favorite
     */
    /**
     * User wants to record the selected item
     */
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btnDelete;
    private javax.swing.JButton btnRecord;
    private javax.swing.JButton btnRecordAll;
    private org.kuehntopf.streamtastic.gui.components.GlossyPanel header;
    private javax.swing.JLabel lblAdd;
    private javax.swing.JScrollPane scrollpane;
    private javax.swing.JTable tblFavorites;
    private javax.swing.JTextField textfieldAdd;
    private javax.swing.JToolBar toolbar;
    // End of variables declaration//GEN-END:variables

    
}
