/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.utils;

import java.io.IOException;
import javax.naming.OperationNotSupportedException;
import org.kuehntopf.streamtastic.core.storage.Config;

/**
 * Player class
 * Provides easy access to an external player
 * @author akuehntopf
 */
public class Player 
{
    /**
     * Checks if a valid player
     * command has been set in config file
     */
    public static boolean
    isAvailable()
    {
        String playercmd = Config.getInstance().getProperty("PLAYER_CMD");
        if (playercmd == null || playercmd.equals(""))
            return false;
        else
            return true;
    }
    
    /**
     * Starts the player
     * with the specified URL as argument
     */
    public static void
    play(String url) 
    throws OperationNotSupportedException
    {
       // Check if player is available.
       // throw an exception if it isn't
       if (!isAvailable())
           throw new OperationNotSupportedException("Player not set");
       
       // Launch the Player
       String playercmd = Config.getInstance().getProperty("PLAYER_CMD");
       String[] args = new String[]{playercmd, url};
       try
       {
            Runtime.getRuntime().exec(args);
       } catch (IOException e)
       {
            e.printStackTrace();
       }
    }
}
