/*
 * Streamtastic Streamripper Frontend
 * Copyright 2008 Andreas Kühntopf <andreas@kuehntopf.org>
 * 
 * This file is part of Streamtastic.
 *
 * Streamtastic is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Streamtastic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Streamtastic.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.kuehntopf.streamtastic.utils;

import java.io.File;
import java.util.ResourceBundle;
import javax.swing.ImageIcon;
import javax.swing.JOptionPane;

/**
 * Utilities for i18n, etc
 * @author akuehntopf
 */
public class Utilities 
{   
    public static String bundle = 
            "org.kuehntopf.streamtastic.resources.i18n.streamtastic";
        
    /**
     * Loads an icon at the specific path
     * relative to the icons subdirectory
     * @param path Relative path
     * @return Loaded ImageIcon
     */
    public static ImageIcon 
    loadIcon(String path)
    {
        String pathPrefix = "/org/kuehntopf/streamtastic/resources/icons";     
        return new ImageIcon(Utilities.class.getResource(
                pathPrefix + "/" + path));
    }

    /**
     * Returns the User's home directory
     * @return Home dir
     */
    public static String 
    getHome()
    {
       return System.getProperty("user.home");
    }

    /**
     * Gets a localized String
     * @param key key to search for
     */
    public static String
    getString(String key)
    {
        return ResourceBundle.getBundle(bundle).getString(key);
    }
    
    /**
     * Returns the User's storage directory
     * @return the storage directory
     */
    public static String 
    getStorageDirectory()
    {
        String dir = getHome() + File.separator + ".streamtastic";
        File f = new File(dir);
        if (!f.exists())
        {
            f.mkdir();
        }
        return dir;
    }
    
    /**
     * Displays an Error message
     * @param text text to display 
     */
    public static void 
    showError(String text)
    {            
        JOptionPane.showMessageDialog(null, text, getString("ERROR"), 
                JOptionPane.ERROR_MESSAGE);
    }    
    
    /**
     * Displays a localized error 
     * message
     */
    public static void
    showLocalizedError(String key)
    {
        showError(getString(key));
    }
}
